]> git.mxchange.org Git - quix0rs-gnu-social.git/commitdiff
change Action::init() to Action::prepare() to avoid conflict with RSS10Action::init()
authorEvan Prodromou <evan@controlyourself.ca>
Wed, 3 Dec 2008 17:32:25 +0000 (12:32 -0500)
committerEvan Prodromou <evan@controlyourself.ca>
Wed, 3 Dec 2008 17:32:25 +0000 (12:32 -0500)
darcs-hash:20081203173225-5ed1f-e5ebfb202ed4a84c90851d0faa025ad09774d2c3.gz

actions/shownotice.php
index.php
lib/action.php

index ca1b134977cdd1f6c6c13ec95460b8789fba1cb3..a8f5060d247339c47b4df654f298298da3a60cd7 100644 (file)
@@ -27,7 +27,7 @@ class ShownoticeAction extends StreamAction {
        var $profile = NULL;
        var $avatar = NULL;
 
-       function init($args) {
+       function prepare($args) {
 
                parent::init($args);
 
index 5c16d2fd501495bd09b2d485b66580a51548b804..ae2e56f25c44a7e290a0ce27f6dcdb62e90e790e 100644 (file)
--- a/index.php
+++ b/index.php
@@ -52,7 +52,7 @@ if (file_exists($actionfile)) {
                }
                $config['db']['database'] = $mirror;
        }
-    if (call_user_func(array($action_obj, 'init'), $_REQUEST)) {
+    if (call_user_func(array($action_obj, 'prepare'), $_REQUEST)) {
                call_user_func(array($action_obj, 'handle'), $_REQUEST);
        }
 } else {
index 16959c53a2b971e7e5fd4985f6737771d6189a60..7a2461bb5cf60640d2bc80d2e940f1eba1e44ff5 100644 (file)
@@ -28,7 +28,7 @@ class Action { // lawsuit
 
        # For initializing members of the class
 
-       function init($argarray) {
+       function prepare($argarray) {
                $this->args =& common_copy_args($argarray);
                return true;
        }
@@ -61,7 +61,7 @@ class Action { // lawsuit
                return (is_string($arg)) ? trim($arg) : $arg;
        }
 
# Note: argarray ignored, since it's now passed in in init()
 
        function handle($argarray=NULL) {
@@ -61,7 +61,7 @@ class Action { // lawsuit
        }
 
-       # Note: argarray ignored, since it's now passed in in init()
+       # Note: argarray ignored, since it's now passed in in prepare()
 
        function handle($argarray=NULL) {